@@ -1,20 +1,15 @@
 """Tests for the BaseFormatter object."""
-from __future__ import annotations
-
 import argparse
-import sys
 from unittest import mock
 
 import pytest
 
-from flake8.formatting import _windows_color
+from flake8 import style_guide
 from flake8.formatting import base
-from flake8.violation import Violation
 
 
 def options(**kwargs):
     """Create an argparse.Namespace instance."""
-    kwargs.setdefault("color", "auto")
     kwargs.setdefault("output_file", None)
     kwargs.setdefault("tee", False)
     return argparse.Namespace(**kwargs)
@@ -50,7 +45,7 @@ def test_format_needs_to_be_implemented():
     formatter = base.BaseFormatter(options())
     with pytest.raises(NotImplementedError):
         formatter.format(
-            Violation("A000", "file.py", 1, 1, "error text", None)
+            style_guide.Violation("A000", "file.py", 1, 1, "error text", None)
         )
 
 
@@ -59,7 +54,9 @@ def test_show_source_returns_nothing_when_not_showing_source():
     formatter = base.BaseFormatter(options(show_source=False))
     assert (
         formatter.show_source(
-            Violation("A000", "file.py", 1, 1, "error text", "line")
+            style_guide.Violation(
+                "A000", "file.py", 1, 1, "error text", "line"
+            )
         )
         == ""
     )
@@ -70,7 +67,7 @@ def test_show_source_returns_nothing_when_there_is_source():
     formatter = base.BaseFormatter(options(show_source=True))
     assert (
         formatter.show_source(
-            Violation("A000", "file.py", 1, 1, "error text", None)
+            style_guide.Violation("A000", "file.py", 1, 1, "error text", None)
         )
         == ""
     )
@@ -99,13 +96,13 @@ def test_show_source_returns_nothing_when_there_is_source():
 def test_show_source_updates_physical_line_appropriately(line1, line2, column):
     """Ensure the error column is appropriately indicated."""
     formatter = base.BaseFormatter(options(show_source=True))
-    error = Violation("A000", "file.py", 1, column, "error", line1)
+    error = style_guide.Violation("A000", "file.py", 1, column, "error", line1)
     output = formatter.show_source(error)
     assert output == line1 + line2
 
 
 @pytest.mark.parametrize("tee", [False, True])
-def test_write_uses_an_output_file(tee, capsys):
+def test_write_uses_an_output_file(tee):
     """Verify that we use the output file when it's present."""
     line = "Something to write"
     source = "source"
@@ -114,11 +111,16 @@ def test_write_uses_an_output_file(tee, capsys):
     formatter = base.BaseFormatter(options(tee=tee))
     formatter.output_fd = filemock
 
-    formatter.write(line, source)
-    if tee:
-        assert capsys.readouterr().out == f"{line}\n{source}\n"
-    else:
-        assert capsys.readouterr().out == ""
+    with mock.patch("flake8.formatting.base.print") as print_func:
+        formatter.write(line, source)
+        if tee:
+            assert print_func.called
+            assert print_func.mock_calls == [
+                mock.call(line, end="\n"),
+                mock.call(source, end="\n"),
+            ]
+        else:
+            assert not print_func.called
 
     assert filemock.write.called is True
     assert filemock.write.call_count == 2
@@ -128,58 +130,21 @@ def test_write_uses_an_output_file(tee, capsys):
     ]
 
 
-def test_write_produces_stdout(capsys):
-    """Verify that we write to stdout without an output file."""
+@mock.patch("flake8.formatting.base.print")
+def test_write_uses_print(print_function):
+    """Verify that we use the print function without an output file."""
     line = "Something to write"
     source = "source"
 
     formatter = base.BaseFormatter(options())
     formatter.write(line, source)
 
-    assert capsys.readouterr().out == f"{line}\n{source}\n"
-
-
-def test_color_always_is_true():
-    """Verify that color='always' sets it to True."""
-    formatter = base.BaseFormatter(options(color="always"))
-    assert formatter.color is True
-
-
-def _mock_isatty(val):
-    attrs = {"isatty.return_value": val}
-    return mock.patch.object(sys, "stdout", **attrs)
-
-
-def _mock_windows_color(val):
-    return mock.patch.object(_windows_color, "terminal_supports_color", val)
-
-
-def test_color_auto_is_true_for_tty():
-    """Verify that color='auto' sets it to True for a tty."""
-    with _mock_isatty(True), _mock_windows_color(True):
-        formatter = base.BaseFormatter(options(color="auto"))
-    assert formatter.color is True
-
-
-def test_color_auto_is_false_without_tty():
-    """Verify that color='auto' sets it to False without a tty."""
-    with _mock_isatty(False), _mock_windows_color(True):
-        formatter = base.BaseFormatter(options(color="auto"))
-    assert formatter.color is False
-
-
-def test_color_auto_is_false_if_not_supported_on_windows():
-    """Verify that color='auto' is False if not supported on windows."""
-    with _mock_isatty(True), _mock_windows_color(False):
-        formatter = base.BaseFormatter(options(color="auto"))
-    assert formatter.color is False
-
-
-def test_color_never_is_false():
-    """Verify that color='never' sets it to False despite a tty."""
-    with _mock_isatty(True), _mock_windows_color(True):
-        formatter = base.BaseFormatter(options(color="never"))
-    assert formatter.color is False
+    assert print_function.called is True
+    assert print_function.call_count == 2
+    assert print_function.mock_calls == [
+        mock.call(line, end="\n"),
+        mock.call(source, end="\n"),
+    ]
 
 
 class AfterInitFormatter(base.BaseFormatter):
@@ -208,7 +173,7 @@ def test_handle_formats_the_error():
     """Verify that a formatter will call format from handle."""
     formatter = FormatFormatter(options(show_source=False))
     filemock = formatter.output_fd = mock.Mock()
-    error = Violation(
+    error = style_guide.Violation(
         code="A001",
         filename="example.py",
         line_number=1,
